Event<E> class abstract

An event is the basic way we pass data into the system to solicit a response.

Implementers

Constructors

Event()

Properties

data → E
no setter
hashCode int
The hash code for this object.
no setterinherited
originId String
no setter
propagateDown bool
no setter
propagateUp bool
no setter
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span bool
no setter
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited